package net.minecraftforge.common;

import java.io.File;
import java.io.IOException;
import java.nio.file.Files;

import org.apache.logging.log4j.Level;

import net.minecraft.world.chunk.storage.IChunkLoader;
import net.minecraft.world.storage.IPlayerFileData;
import net.minecraft.world.storage.ISaveHandler;
import net.minecraft.world.MinecraftException;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.world.storage.WorldInfo;
import net.minecraft.world.WorldProvider;
import net.minecraft.world.WorldServer;
import net.minecraftforge.fml.common.FMLLog;

//Class used internally to provide the world specific data directories.

public class WorldSpecificSaveHandler implements ISaveHandler
{
    private WorldServer world;
    private ISaveHandler parent;
    private File dataDir;

    public WorldSpecificSaveHandler(WorldServer world, ISaveHandler parent)
    {
        this.world = world;
        this.parent = parent;
    }

    @Override public WorldInfo func_75757_d() { return parent.func_75757_d(); }
    @Override public void func_75762_c() throws MinecraftException { parent.func_75762_c(); }
    @Override public IChunkLoader func_75763_a(WorldProvider var1) { return parent.func_75763_a(var1); }
    @Override public void func_75755_a(WorldInfo var1, NBTTagCompound var2) { parent.func_75755_a(var1, var2); }
    @Override public void func_75761_a(WorldInfo var1){ parent.func_75761_a(var1); }
    @Override public IPlayerFileData func_75756_e() { return parent.func_75756_e(); }
    @Override public void func_75759_a() { parent.func_75759_a(); }
    @Override public String func_75760_g() { return parent.func_75760_g(); }
    @Override public File func_75765_b() { return parent.func_75765_b(); }

    @Override
    public File func_75758_b(String name)
    {
        if (dataDir == null) //Delayed down here do that world has time to be initalized first.
        {
            dataDir = new File(world.getChunkSaveLocation(), "data");
            dataDir.mkdirs();
        }
        File file = new File(dataDir, name + ".dat");
        if (!file.exists() && name.equalsIgnoreCase("FORTRESS") && world.field_73011_w.func_177502_q() == -1) //Only copy over the fortress.dat for the vanilla nether.
        {
            File parentFile = parent.func_75758_b(name);
            if (parentFile.exists())
            {
                try
                {
                    Files.copy(parentFile.toPath(), file.toPath());
                }
                catch (IOException e)
                {
                    FMLLog.log(Level.ERROR, e, "A critical error occured copying fortress.dat to world specific dat folder - new file will be created.");
                }
            }
        }
        return file;
    }

}
