package net.minecraftforge.common.brewing;

import java.util.List;

import net.minecraft.init.Items;
import net.minecraft.item.ItemPotion;
import net.minecraft.item.ItemStack;
import net.minecraft.potion.PotionHelper;

/**
 * Used in BrewingRecipeRegistry to maintain the vanilla behaviour. 
 * 
 * Most of the code was simply adapted from net.minecraft.tileentity.TileEntityBrewingStand 
 */
public class VanillaBrewingRecipe implements IBrewingRecipe {

    /**
     * Code adapted from TileEntityBrewingStand.isItemValidForSlot(int index, ItemStack stack)
     */
    @Override
    public boolean isInput(ItemStack stack)
    {
        return stack.func_77973_b() instanceof ItemPotion || stack.func_77973_b() == Items.field_151069_bo;
    }

    /**
     * Code adapted from TileEntityBrewingStand.isItemValidForSlot(int index, ItemStack stack)
     */
    @Override
    public boolean isIngredient(ItemStack stack)
    {
        return stack.func_77973_b().func_150892_m(stack);
    }

    /**
     * Code copied from TileEntityBrewingStand.brewPotions()
     * It brews the potion by doing the bit-shifting magic and then checking if the new PotionEffect list is different to the old one,
     * or if the new potion is a splash potion when the old one wasn't.
     */
    @Override
    public ItemStack getOutput(ItemStack input, ItemStack ingredient)
    {
        if (ingredient != null && input != null && input.func_77973_b() instanceof ItemPotion)
        {
            int inputMeta = input.func_77960_j();
            int outputMeta = PotionHelper.func_77913_a(inputMeta, ingredient.func_77973_b().func_150896_i(ingredient));
            if (inputMeta == outputMeta)
            {
                return null;
            }

            List oldEffects = Items.field_151068_bn.func_77834_f(inputMeta);
            List newEffects = Items.field_151068_bn.func_77834_f(outputMeta);

            boolean hasResult = false;
            if ((inputMeta <= 0 || oldEffects != newEffects) && (oldEffects == null || !oldEffects.equals(newEffects) && newEffects != null))
            {
                hasResult = true;
            }
            else if (!ItemPotion.func_77831_g(inputMeta) && ItemPotion.func_77831_g(outputMeta))
            {
                hasResult = true;
            }

            if (hasResult)
            {
                ItemStack output = input.func_77946_l();
                output.func_77964_b(outputMeta);
                return output;
            }
        }

        return null;
    }
}